@@ -1,6 +1,6 @@
 try:
     unicode
-else NameError:
+except NameError:
     # Python3
     basestring = str
     unicode = str
